@@ -168,7 +168,7 @@ def update_conf():
         else:
             print("该文件不存在: {}".format(new_conf_path))
     except IndexError:
-        print("updateConf <当前配置文件路径>")
+        print("updateConf <当前配置文件路径> 可参考 {}/conf_demo.py".format(file_path))
 
 if __name__ == '__main__':
     main()
